#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_BASE_URL: https://sachachua.com
* STARTED Changing Org Mode underlines to the HTML mark element  :org:
:PROPERTIES:
:CREATED: [2024-11-17 Sun 16:16]
:Effort:   0:30
:QUANTIFIED: Emacs
:EXPORT_DATE: 2024-11-17T16:44:36-0500
:EXPORT_ELEVENTY_PERMALINK: /blog/2024/11/changing-org-mode-underlines-to-the-html-mark-element/
:EXPORT_ELEVENTY_FILE_NAME: blog/2024/11/changing-org-mode-underlines-to-the-html-mark-element/
:END:
:LOGBOOK:
CLOCK: [2024-11-17 Sun 16:30]
:END:

Apparently, [[https://developer.mozilla.org/en-US/docs/Web/HTML/Element/mark][HTML has a mark element]] that is useful
for highlighting. ox-html.el in Org Mode doesn't
seem to export that yet. I don't use ~_~ to
underline things because I don't want that
confused with links. Maybe I can override
~org-html-text-markup-alist~ to use it for my own
purposes...

#+begin_src emacs-lisp
(with-eval-after-load 'org
	(setf (alist-get 'underline org-html-text-markup-alist)
				"<mark>%s</mark>"))
#+end_src

Okay, let's try it with:

#+begin_example
Let's see _how that works._
#+end_example

Let's see _how that works._ Oooh, that's promising.

Now, what if I want something fancier, like the
way it can be nice to use different-coloured
highlighters when marking up notes in order to
make certain things jump out easily? A custom link
might come in handy.

#+begin_src emacs-lisp
(defun my-org-highlight-export (link desc format _)
	(pcase format
		((or '11ty 'html)
		 (format "<mark%s>%s</mark>"
						 (if link
								 (format " class=\"%s\"" link)
							 link)
						 desc))))
(with-eval-after-load 'org
	(org-link-set-parameters "hl" :export 'my-org-highlight-export)
	)
#+end_src

A [[hl:green][green highlight]] might be good for ideas, while
[[hl:red][red]] might be good for warnings. ([[hl:green][Idea:]] I wonder
how to font-lock them differently in Emacs...)

I shouldn't rely only on the colours, since people
reading through RSS won't get them and also since
some people are colour-blind. Still, the
highlights could make my blog posts easier to skim
on my website.

Of course, now I want to port [[https://protesilaos.com/emacs/modus-themes][Prot's excellent
colours from the Modus themes]] over to CSS
variables so that I can have colours that make
sense in both light mode and dark mode. Here's a
snippet that exports the colours from one of the
themes:

#+begin_src emacs-lisp :exports code :results silent :eval never-export
(format ":root {\n%s\n}\n"
				(mapconcat
				 (lambda (entry)
					 (format "  --modus-%s: %s;"
									 (symbol-name (car entry))
									 (if (stringp (cadr entry))
											 (cadr entry)
										 (format "var(--modus-%s)" (symbol-name (cadr entry))))))
				 modus-operandi-palette
				 "\n"))
#+end_src

So now my style.css has:

#+begin_src css
/* Based on Modus Operandi by Protesilaous Stavrou */
:root {
   // ...
   --modus-bg-red-subtle: #ffcfbf;
   --modus-bg-green-subtle: #b3fabf;
   --modus-bg-yellow-subtle: #fff576;
   // ...
}
@media (prefers-color-scheme: dark) {
   /* Based on Modus Vivendi by Protesilaous Stavrou */
   :root {
      // ...
      --modus-bg-red-subtle: #620f2a;
      --modus-bg-green-subtle: #00422a;
      --modus-bg-yellow-subtle: #4a4000;
      // ...
   }
}
mark { background-color: var(--modus-bg-yellow-subtle) }
mark.green { background-color: var(--modus-bg-green-subtle) }
mark.red { background-color: var(--modus-bg-red-subtle) }
#+end_src

Interesting, interesting...

